.. rusclasp documentation master file, created by
   sphinx-quickstart on Tue Mar 22 18:46:19 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

rusclasp: сегментатор предикаций
================================

rusclasp_ — это python модуль, позволяющий разбивать предложения русского языка на предикации с восстановлением разрывов.


Содержание:

.. toctree::
   :maxdepth: 2

   usage/index
   internals/index


Исходный код - на github_. Если заметили ошибку, то пишите
в `баг-трекер`_.


.. _rusclasp: https://github.com/gree-gorey/rusclasp
.. _github: https://github.com/gree-gorey/rusclasp
.. _баг-трекер: https://github.com/gree-gorey/rusclasp/issues